==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTrashTableCatalog.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTrashTableCatalog<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public TrashTable trashTable;
	public TrashTableCatalog.TrashTable. TrashTableTypeHeading trashTableTypeHeading;
	public TrashTableCatalog.TrashTable.TrashTableTypeHeading. _34_35_11837729171 _34_35_11837729171;
	public TrashTableCatalog.TrashTable. TrashTableLabelHeading trashTableLabelHeading;
	public TrashTableCatalog.TrashTable.TrashTableLabelHeading. _37_36_0143668709 _37_36_0143668709;
	public TrashTableCatalog.TrashTable. TrashTableDeleteDateHeading trashTableDeleteDateHeading;
	public TrashTableCatalog.TrashTable.TrashTableDeleteDateHeading. _40_41_02138657774 _40_41_02138657774;
	public TrashTableCatalog.TrashTable. TrashTableOperationsHeading trashTableOperationsHeading;

    public AbstractTrashTableCatalog(B box) {
        super(box);
        id("trashTableCatalog");
    }

    @Override
	public void init() {
		super.init();
		if (trashTable == null) trashTable = register(new TrashTable(box()).<TrashTable>id("a1332160849").owner(AbstractTrashTableCatalog.this));
		if (trashTable != null) trashTableTypeHeading = trashTable.trashTableTypeHeading;
		if (trashTableTypeHeading != null) _34_35_11837729171 = trashTable.trashTableTypeHeading._34_35_11837729171;
		if (trashTable != null) trashTableLabelHeading = trashTable.trashTableLabelHeading;
		if (trashTableLabelHeading != null) _37_36_0143668709 = trashTable.trashTableLabelHeading._37_36_0143668709;
		if (trashTable != null) trashTableDeleteDateHeading = trashTable.trashTableDeleteDateHeading;
		if (trashTableDeleteDateHeading != null) _40_41_02138657774 = trashTable.trashTableDeleteDateHeading._40_41_02138657774;
		if (trashTable != null) trashTableOperationsHeading = trashTable.trashTableOperationsHeading;
	}

	public class TrashTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Node>  {
		public TrashTableCatalog.TrashTable. TrashTableTypeHeading trashTableTypeHeading;
		public TrashTableCatalog.TrashTable. TrashTableLabelHeading trashTableLabelHeading;
		public TrashTableCatalog.TrashTable. TrashTableDeleteDateHeading trashTableDeleteDateHeading;
		public TrashTableCatalog.TrashTable. TrashTableOperationsHeading trashTableOperationsHeading;

		public TrashTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (trashTableTypeHeading == null) trashTableTypeHeading = register(new TrashTableTypeHeading(box()).<TrashTableTypeHeading>id("a1418025069").owner(AbstractTrashTableCatalog.this));
			if (trashTableLabelHeading == null) trashTableLabelHeading = register(new TrashTableLabelHeading(box()).<TrashTableLabelHeading>id("a1458302822").owner(AbstractTrashTableCatalog.this));
			if (trashTableDeleteDateHeading == null) trashTableDeleteDateHeading = register(new TrashTableDeleteDateHeading(box()).<TrashTableDeleteDateHeading>id("a2029215892").owner(AbstractTrashTableCatalog.this));
			if (trashTableOperationsHeading == null) trashTableOperationsHeading = register(new TrashTableOperationsHeading(box()).<TrashTableOperationsHeading>id("a1880204121").owner(AbstractTrashTableCatalog.this));
		}


		public TrashTableRow create(org.monet.space.kernel.model.Node item) {
			TrashTableRow row = new TrashTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class TrashTableTypeHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public TrashTableCatalog.TrashTable.TrashTableTypeHeading. _34_35_11837729171 _34_35_11837729171;

			public TrashTableTypeHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_34_35_11837729171 == null) _34_35_11837729171 = register(new _34_35_11837729171(box()).<_34_35_11837729171>id("a_1454943075").owner(AbstractTrashTableCatalog.this));
			}

			public class _34_35_11837729171 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _34_35_11837729171(B box) {
					super(box);
					_value("Type");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class TrashTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public TrashTableCatalog.TrashTable.TrashTableLabelHeading. _37_36_0143668709 _37_36_0143668709;

			public TrashTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_37_36_0143668709 == null) _37_36_0143668709 = register(new _37_36_0143668709(box()).<_37_36_0143668709>id("a471997135").owner(AbstractTrashTableCatalog.this));
			}

			public class _37_36_0143668709 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _37_36_0143668709(B box) {
					super(box);
					_value("Title");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class TrashTableDeleteDateHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public TrashTableCatalog.TrashTable.TrashTableDeleteDateHeading. _40_41_02138657774 _40_41_02138657774;

			public TrashTableDeleteDateHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_40_41_02138657774 == null) _40_41_02138657774 = register(new _40_41_02138657774(box()).<_40_41_02138657774>id("a_242706563").owner(AbstractTrashTableCatalog.this));
			}

			public class _40_41_02138657774 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _40_41_02138657774(B box) {
					super(box);
					_value("Delete date");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class TrashTableOperationsHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {

			public TrashTableOperationsHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTrashTableCatalog.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTrashTableCatalog<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public TrashTable trashTable;
	public TrashTableCatalog.TrashTable. TrashTableTypeHeading trashTableTypeHeading;
	public TrashTableCatalog.TrashTable.TrashTableTypeHeading. _34_35_11837729171 _34_35_11837729171;
	public TrashTableCatalog.TrashTable. TrashTableLabelHeading trashTableLabelHeading;
	public TrashTableCatalog.TrashTable.TrashTableLabelHeading. _37_36_0143668709 _37_36_0143668709;
	public TrashTableCatalog.TrashTable. TrashTableDeleteDateHeading trashTableDeleteDateHeading;
	public TrashTableCatalog.TrashTable.TrashTableDeleteDateHeading. _40_41_02138657774 _40_41_02138657774;
	public TrashTableCatalog.TrashTable. TrashTableOperationsHeading trashTableOperationsHeading;

    public AbstractTrashTableCatalog(B box) {
        super(box);
        id("trashTableCatalog");
    }

    @Override
	public void init() {
		super.init();
		if (trashTable == null) trashTable = register(new TrashTable(box()).<TrashTable>id("a1332160849").owner(AbstractTrashTableCatalog.this));
		if (trashTable != null) trashTableTypeHeading = trashTable.trashTableTypeHeading;
		if (trashTableTypeHeading != null) _34_35_11837729171 = trashTable.trashTableTypeHeading._34_35_11837729171;
		if (trashTable != null) trashTableLabelHeading = trashTable.trashTableLabelHeading;
		if (trashTableLabelHeading != null) _37_36_0143668709 = trashTable.trashTableLabelHeading._37_36_0143668709;
		if (trashTable != null) trashTableDeleteDateHeading = trashTable.trashTableDeleteDateHeading;
		if (trashTableDeleteDateHeading != null) _40_41_02138657774 = trashTable.trashTableDeleteDateHeading._40_41_02138657774;
		if (trashTable != null) trashTableOperationsHeading = trashTable.trashTableOperationsHeading;
	}

    @Override
    public void remove() {
        super.remove();
	    if (trashTable != null) trashTable.unregister();
	}

	public class TrashTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Node>  {
		public TrashTableCatalog.TrashTable. TrashTableTypeHeading trashTableTypeHeading;
		public TrashTableCatalog.TrashTable. TrashTableLabelHeading trashTableLabelHeading;
		public TrashTableCatalog.TrashTable. TrashTableDeleteDateHeading trashTableDeleteDateHeading;
		public TrashTableCatalog.TrashTable. TrashTableOperationsHeading trashTableOperationsHeading;

		public TrashTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (trashTableTypeHeading == null) trashTableTypeHeading = register(new TrashTableTypeHeading(box()).<TrashTableTypeHeading>id("a1418025069").owner(AbstractTrashTableCatalog.this));
			if (trashTableLabelHeading == null) trashTableLabelHeading = register(new TrashTableLabelHeading(box()).<TrashTableLabelHeading>id("a1458302822").owner(AbstractTrashTableCatalog.this));
			if (trashTableDeleteDateHeading == null) trashTableDeleteDateHeading = register(new TrashTableDeleteDateHeading(box()).<TrashTableDeleteDateHeading>id("a2029215892").owner(AbstractTrashTableCatalog.this));
			if (trashTableOperationsHeading == null) trashTableOperationsHeading = register(new TrashTableOperationsHeading(box()).<TrashTableOperationsHeading>id("a1880204121").owner(AbstractTrashTableCatalog.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (trashTableTypeHeading != null) trashTableTypeHeading.unregister();
			if (trashTableLabelHeading != null) trashTableLabelHeading.unregister();
			if (trashTableDeleteDateHeading != null) trashTableDeleteDateHeading.unregister();
			if (trashTableOperationsHeading != null) trashTableOperationsHeading.unregister();
		}


		public TrashTableRow create(org.monet.space.kernel.model.Node item) {
			TrashTableRow row = new TrashTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class TrashTableTypeHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public TrashTableCatalog.TrashTable.TrashTableTypeHeading. _34_35_11837729171 _34_35_11837729171;

			public TrashTableTypeHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_34_35_11837729171 == null) _34_35_11837729171 = register(new _34_35_11837729171(box()).<_34_35_11837729171>id("a_1454943075").owner(AbstractTrashTableCatalog.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_34_35_11837729171 != null) _34_35_11837729171.unregister();
			}

			public class _34_35_11837729171 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _34_35_11837729171(B box) {
					super(box);
					_value("Type");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class TrashTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public TrashTableCatalog.TrashTable.TrashTableLabelHeading. _37_36_0143668709 _37_36_0143668709;

			public TrashTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_37_36_0143668709 == null) _37_36_0143668709 = register(new _37_36_0143668709(box()).<_37_36_0143668709>id("a471997135").owner(AbstractTrashTableCatalog.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_37_36_0143668709 != null) _37_36_0143668709.unregister();
			}

			public class _37_36_0143668709 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _37_36_0143668709(B box) {
					super(box);
					_value("Title");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class TrashTableDeleteDateHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public TrashTableCatalog.TrashTable.TrashTableDeleteDateHeading. _40_41_02138657774 _40_41_02138657774;

			public TrashTableDeleteDateHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_40_41_02138657774 == null) _40_41_02138657774 = register(new _40_41_02138657774(box()).<_40_41_02138657774>id("a_242706563").owner(AbstractTrashTableCatalog.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_40_41_02138657774 != null) _40_41_02138657774.unregister();
			}

			public class _40_41_02138657774 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _40_41_02138657774(B box) {
					super(box);
					_value("Delete date");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class TrashTableOperationsHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {

			public TrashTableOperationsHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
